@@ -1,6 +1,6 @@
 #! /usr/bin/python
 # -*- coding: utf-8 -*-
-# $Id: test_dbapi20.py 849 2016-02-09 13:14:26Z cito $
+# $Id: test_dbapi20.py 881 2016-07-23 19:41:16Z cito $
 
 try:
     import unittest2 as unittest  # for Python < 2.7
@@ -28,6 +28,9 @@ except (ImportError, ValueError):
     except ImportError:
         pass
 
+import gc
+import sys
+
 from datetime import date, time, datetime, timedelta
 from uuid import UUID as Uuid
 
@@ -79,12 +82,21 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
     def tearDown(self):
         dbapi20.DatabaseAPI20Test.tearDown(self)
 
-    def testVersion(self):
+    def test_version(self):
         v = pgdb.version
         self.assertIsInstance(v, str)
         self.assertIn('.', v)
         self.assertEqual(pgdb.__version__, v)
 
+    def test_connect_kwargs(self):
+        application_name = 'PyGreSQL DB API 2.0 Test'
+        self.connect_kw_args['application_name'] = application_name
+        con = self._connect()
+        cur = con.cursor()
+        cur.execute("select application_name from pg_stat_activity"
+            " where application_name = %s", (application_name,))
+        self.assertEqual(cur.fetchone(), (application_name,))
+
     def test_percent_sign(self):
         con = self._connect()
         cur = con.cursor()
@@ -567,6 +579,7 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         con = self._connect()
         try:
             cur = con.cursor()
+            cur.execute("set timezone = UTC")
             cur.execute("create table %s ("
                 "d date, t time,  ts timestamp,"
                 "tz timetz, tsz timestamptz)" % table)
@@ -1206,6 +1219,31 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         self.assertEqual('record', pgdb.RECORD)
         self.assertNotEqual('_record', pgdb.RECORD)
 
+    def test_no_close(self):
+        data = ('hello', 'world')
+        con = self._connect()
+        cur = con.cursor()
+        cur.build_row_factory = lambda: tuple
+        cur.execute("select %s, %s", data)
+        row = cur.fetchone()
+        self.assertEqual(row, data)
+
+    def test_memory_leaks(self):
+        ids = set()
+        objs = []
+        add_ids = ids.update
+        gc.collect()
+        objs[:] = gc.get_objects()
+        add_ids(id(obj) for obj in objs)
+        self.test_no_close()
+        gc.collect()
+        objs[:] = gc.get_objects()
+        objs[:] = [obj for obj in objs if id(obj) not in ids]
+        if objs and sys.version_info[:3] in ((3, 5, 0), (3, 5, 1)):
+            # workaround for Python issue 26811
+            objs[:] = [obj for obj in objs if repr(obj) != '(<NULL>,)']
+        self.assertEqual(len(objs), 0)
+
 
 if __name__ == '__main__':
     unittest.main()
